@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 import gtk
 import gobject
+import pango
 import gettext
 import os
 import re
@@ -31,6 +32,7 @@ try:
 except ImportError:
     ssl = None
 import dis
+from threading import Lock
 
 _ = gettext.gettext
 
@@ -243,7 +245,7 @@ def file_selection(title, filename='', parent=None,
             pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(filename, 128, 128)
             img.set_from_pixbuf(pixbuf)
             have_preview = True
-        except:
+        except Exception:
             have_preview = False
         win.set_preview_widget_active(have_preview)
         return
@@ -266,7 +268,7 @@ def file_selection(title, filename='', parent=None,
                 CONFIG['client.default_path'] = \
                         os.path.dirname(filepath)
                 CONFIG.save()
-            except:
+            except Exception:
                 pass
         parent.present()
         win.destroy()
@@ -278,7 +280,7 @@ def file_selection(title, filename='', parent=None,
             try:
                 CONFIG['client.default_path'] = \
                         os.path.dirname(filenames[0])
-            except:
+            except Exception:
                 pass
         parent.present()
         win.destroy()
@@ -291,11 +293,11 @@ def file_open(filename, type, parent, print_p=False):
             operation = 'print'
         try:
             os.startfile(os.path.normpath(filename), operation)
-        except:
+        except Exception:
             # Try without operation, it is not supported on version < 2.5
             try:
                 os.startfile(os.path.normpath(filename))
-            except:
+            except Exception:
                 save_name = file_selection(_('Save As...'), parent=parent,
                         action=gtk.FILE_CHOOSER_ACTION_SAVE)
                 if save_name:
@@ -313,7 +315,7 @@ def file_open(filename, type, parent, print_p=False):
             if not pid:
                 try:
                     os.execv('/usr/bin/open', ['/usr/bin/open', filename])
-                except:
+                except Exception:
                     sys.exit(0)
             time.sleep(0.1)
             sys.exit(0)
@@ -353,7 +355,7 @@ def file_open(filename, type, parent, print_p=False):
         if not pid:
             try:
                 os.execv(prog, args)
-            except:
+            except Exception:
                 sys.exit(0)
         time.sleep(0.1)
         sys.exit(0)
@@ -380,7 +382,7 @@ def mailto(to=None, cc=None, subject=None, body=None, attachment=None):
             if not pid:
                 try:
                     os.execv(prog, args)
-                except:
+                except Exception:
                     sys.exit(0)
             time.sleep(0.1)
             sys.exit(0)
@@ -460,6 +462,7 @@ def error(title, parent, details):
     textview.set_buffer(buf)
     textview.set_editable(False)
     textview.set_sensitive(True)
+    textview.modify_font(pango.FontDescription("monospace"))
     box.pack_start(textview, False, False)
 
     viewport.add(box)
@@ -799,6 +802,8 @@ This record has been modified while you were editing it.
                 parent, context, ['form', 'tree'])
     return False
 
+PLOCK = Lock()
+
 def process_exception(exception, parent, *args):
     global _USERNAME, _DATABASE, _SOCK
     if str(exception.args[0]) == 'BadFingerprint':
@@ -813,28 +818,33 @@ def process_exception(exception, parent, *args):
             message(_('Connection error!\n' \
                     'Unable to connect to the server!'), parent)
             return False
+        if not PLOCK.acquire(False):
+            return False
         hostname = rpc._SOCK.hostname
         port = rpc._SOCK.port
-        while True:
-            password = ask(_('Password:'), parent, visibility=False)
-            if password is None:
-                raise Exception('NotLogged')
-            res = rpc.login(rpc._USERNAME, password, hostname, port,
-                    rpc._DATABASE)
-            from tryton.gui.main import Main
-            Main.get_main().refresh_ssl()
-            if res == -1:
-                message(_('Connection error!\n' \
-                        'Unable to connect to the server!'), parent)
-                return False
-            if res < 0:
-                continue
-            if args:
-                try:
-                    return rpc.execute(*args)
-                except Exception, exception:
-                    return process_exception(exception, parent, *args)
-            return True
+        try:
+            while True:
+                password = ask(_('Password:'), parent, visibility=False)
+                if password is None:
+                    raise Exception('NotLogged')
+                res = rpc.login(rpc._USERNAME, password, hostname, port,
+                        rpc._DATABASE)
+                from tryton.gui.main import Main
+                Main.get_main().refresh_ssl()
+                if res == -1:
+                    message(_('Connection error!\n' \
+                            'Unable to connect to the server!'), parent)
+                    return False
+                if res < 0:
+                    continue
+                if args:
+                    try:
+                        return rpc.execute(*args)
+                    except Exception, exception:
+                        return process_exception(exception, parent, *args)
+                return True
+        finally:
+            PLOCK.release()
 
     if exception.args[0] == 'ConcurrencyException':
         if len(args) >= 6:
@@ -1009,8 +1019,8 @@ class RPCProgress(object):
                     win.set_modal(True)
                     win.show_all()
                 progressbar.pulse()
-                while gtk.events_pending():
-                    gtk.main_iteration()
+            while gtk.events_pending():
+                gtk.main_iteration()
         if win:
             win.destroy()
             while gtk.events_pending():
@@ -1078,7 +1088,7 @@ def text_to_float_time(text, conv=None):
     try:
         try:
             return locale.atof(text)
-        except:
+        except Exception:
             pass
         if conv:
             tmp_conv = FLOAT_TIME_CONV.copy()
@@ -1104,7 +1114,7 @@ def text_to_float_time(text, conv=None):
             try:
                 value += abs(locale.atof(buf))
                 continue
-            except:
+            except Exception:
                 pass
             for sep in conv.keys():
                 if buf.endswith(sep):
@@ -1113,7 +1123,7 @@ def text_to_float_time(text, conv=None):
         if text.startswith('-'):
             value *= -1
         return value
-    except:
+    except Exception:
         return 0.0
 
 def float_time_to_text(val, conv=None):
