@@ -185,7 +185,7 @@ class DateEntry(gtk.Entry):
         try:
             time.strptime(self.compute_date(text, default=default, year='2000'),
                     self.format)
-        except:
+        except Exception:
             return False
         return True
 
@@ -194,7 +194,7 @@ class DateEntry(gtk.Entry):
         date = self.compute_date(self.get_text())
         try:
             res = datetime.datetime(*time.strptime(date, self.format)[:6])
-        except:
+        except Exception:
             return None
         self.set_text(date)
         return res
@@ -327,7 +327,7 @@ def compute_date(cmd, dt, format):
                 dt = datetime.datetime.now()
             try:
                 return f(dt, groups)
-            except:
+            except Exception:
                 continue
 
 if __name__ == '__main__':
