@@ -13,6 +13,7 @@ import tryton.common as common
 from tryton.action import Action
 from tryton.gui.window import Window
 from tryton.gui.window.preference import Preference
+from tryton.gui.window import Limit
 from tryton.gui.window import FileActions
 from tryton.gui.window import Email
 from tryton.gui.window.dblogin import DBLogin
@@ -29,12 +30,12 @@ import tryton.plugins
 import pango
 import time
 try:
-    import igemacintegration
+    import gtk_osxapplication
 except ImportError:
-    igemacintegration = None
+    gtk_osxapplication = None
 try:
     import gtkspell
-except:
+except Exception:
     gtkspell = None
 
 _ = gettext.gettext
@@ -62,6 +63,11 @@ class Main(object):
         self.accel_group = gtk.AccelGroup()
         self.window.add_accel_group(self.accel_group)
 
+        self.macapp = None
+        if gtk_osxapplication is not None:
+            self.macapp = gtk_osxapplication.OSXApplication()
+            self.macapp.connect("NSApplicationBlockTermination", self.sig_close)
+
         gtk.accel_map_add_entry('<tryton>/File/Connect', gtk.keysyms.O,
                 gtk.gdk.CONTROL_MASK)
         gtk.accel_map_add_entry('<tryton>/File/Quit', gtk.keysyms.Q,
@@ -123,13 +129,9 @@ class Main(object):
         self.set_statusbar()
         self.set_menubar()
 
-        if igemacintegration:
-            self.macmenu = igemacintegration.MacMenu()
-            quit_item = gtk.MenuItem(_('Quit'))
-            quit_item.connect('activate', self.sig_close)
-            self.macmenu.set_quit_menu_item(quit_item)
-            self.macdock = igemacintegration.MacDock()
-            self.macdock.connect('quit-activate', self.sig_close)
+        if self.macapp is not None:
+            self.macapp.ready()
+
 
         self.vbox.pack_start(toolbar, False, True)
 
@@ -258,7 +260,19 @@ class Main(object):
         menu_help.set_accel_group(self.accel_group)
         menu_help.set_accel_path('<tryton>/Help')
 
-        self.menubar.show_all()
+        if self.macapp is not None:
+            self.menubar.set_no_show_all(True)
+            self.macapp.set_menu_bar(self.menubar)
+            self.macapp.insert_app_menu_item(self.aboutitem,0)
+            menuitem_file.show_all()
+            menuitem_user.show_all()
+            menuitem_form.show_all()
+            menuitem_options.show_all()
+            menuitem_plugins.show_all()
+            menuitem_shortcut.show_all()
+            menuitem_help.show_all()
+        else:
+            self.menubar.show_all()
 
     def set_statusbar(self):
         update = True
@@ -352,7 +366,6 @@ class Main(object):
         imagemenuitem_db_drop.set_accel_path('<tryton>/File/Database/Drop Database')
         menu_database.add(imagemenuitem_db_drop)
 
-        menu_file.add(gtk.SeparatorMenuItem())
 
         imagemenuitem_close = gtk.ImageMenuItem(_('_Quit...'), self.accel_group)
         image = gtk.Image()
@@ -360,7 +373,9 @@ class Main(object):
         imagemenuitem_close.set_image(image)
         imagemenuitem_close.connect('activate', self.sig_close)
         imagemenuitem_close.set_accel_path('<tryton>/File/Quit')
-        menu_file.add(imagemenuitem_close)
+        if self.macapp is None:
+            menu_file.add(gtk.SeparatorMenuItem())
+            menu_file.add(imagemenuitem_close)
         return menu_file
 
     def _set_menu_user(self):
@@ -736,6 +751,12 @@ class Main(object):
         if (CONFIG['client.form_tab'] or 'left') == 'bottom':
             radiomenuitem_bottom.set_active(True)
 
+        menuitem_limit = gtk.MenuItem(_('Search Limit...'))
+        self.menuitem_limit = menuitem_limit
+        menuitem_limit.connect('activate', self.sig_limit)
+        menuitem_limit.set_accel_path('<tryton>/Options/Search Limit')
+        menu_options.add(menuitem_limit)
+
         menuitem_actions = gtk.MenuItem(_('File _Actions...'))
         self.menuitem_actions = menuitem_actions
         menuitem_actions.connect('activate', self.sig_file_actions)
@@ -791,7 +812,6 @@ class Main(object):
         imagemenuitem_shortcuts.set_accel_path('<tryton>/Help/Keyboard Shortcuts')
         menu_help.add(imagemenuitem_shortcuts)
 
-        menu_help.add(gtk.SeparatorMenuItem())
 
         imagemenuitem_about = gtk.ImageMenuItem(_('_About...'))
         image = gtk.Image()
@@ -799,7 +819,11 @@ class Main(object):
         imagemenuitem_about.set_image(image)
         imagemenuitem_about.connect('activate', self.sig_about)
         imagemenuitem_about.set_accel_path('<tryton>/Help/About')
-        menu_help.add(imagemenuitem_about)
+        self.aboutitem = imagemenuitem_about
+        if self.macapp is None:
+            menu_help.add(gtk.SeparatorMenuItem())
+            menu_help.add(imagemenuitem_about)
+
         return menu_help
 
     def _set_toolbar(self):
@@ -936,7 +960,7 @@ class Main(object):
             try:
                 shortcuts = rpc.execute('model', 'ir.ui.view_sc', 'get_sc',
                         user, 'ir.ui.menu', rpc.CONTEXT)
-            except:
+            except Exception:
                 shortcuts = []
         menu = gtk.Menu()
         for shortcut in shortcuts:
@@ -1006,6 +1030,9 @@ class Main(object):
     def sig_form_tab(option):
         CONFIG['client.form_tab'] = option
 
+    def sig_limit(self, widget):
+        Limit(self.window).run()
+
     def sig_file_actions(self, widget):
         FileActions(self.window).run()
 
@@ -1078,12 +1105,14 @@ class Main(object):
             if not rpc._USER:
                 return
             if not exception:
-                res = rpc.execute('model', 'res.request', 'request_get')
+                res = rpc.execute('model', 'res.request', 'request_get',
+                        rpc.CONTEXT)
                 if not res:
                     return ([], [])
                 ids, ids2 = res
             else:
-                ids, ids2 = rpc.execute('model', 'res.request', 'request_get')
+                ids, ids2 = rpc.execute('model', 'res.request', 'request_get',
+                        rpc.CONTEXT)
             label = _('Requests (%s/%s)') % (len(ids), len(ids2))
             self.buttons['but_request'].set_label(label)
             self.tooltips.set_tip(self.buttons['but_request'], label)
@@ -1096,7 +1125,7 @@ class Main(object):
                         len(ids2))
             self.sb_requests.set_text(message)
             return (ids, ids2)
-        except:
+        except Exception:
             if exception:
                 raise
             return ([], [])
@@ -1123,7 +1152,7 @@ class Main(object):
             try:
                 prefs = rpc.execute('model', 'res.user', 'get_preferences',
                         False, rpc.CONTEXT)
-            except:
+            except Exception:
                 prefs = None
             if prefs and 'language_direction' in prefs:
                 translate.set_language_direction(prefs['language_direction'])
@@ -1277,13 +1306,17 @@ class Main(object):
         CONFIG.save()
         if hasattr(gtk, 'accel_map_save'):
             gtk.accel_map_save(os.path.join(get_config_dir(), 'accel.map'))
-        gtk.main_quit()
+
+        if gtk.main_level() > 0:
+            gtk.main_quit()
 
     def sig_close(self, widget):
         if common.sur(_("Do you really want to quit?"), parent=self.window):
             if not self.sig_logout(widget):
                 return False
             Main.sig_quit()
+        else:
+            return True
 
     def sig_delete(self, widget, event):
         if common.sur(_("Do you really want to quit?"), parent=self.window):
