@@ -19,7 +19,7 @@ class EvalEnvironment(dict):
 
     def __getitem__(self, item):
         if item == '_parent_' + self.parent.parent_name and self.parent.parent:
-            return EvalEnvironment(self.parent.parent)
+            return EvalEnvironment(self.parent.parent, self.check_load)
         return self.parent.get_eval(check_load=self.check_load)[item]
 
     def __getattr__(self, item):
@@ -28,7 +28,7 @@ class EvalEnvironment(dict):
     def get(self, item, default=None):
         try:
             return self.__getattr__(item)
-        except:
+        except Exception:
             pass
         return super(EvalEnvironment, self).get(item, default)
 
@@ -50,7 +50,7 @@ class Record(SignalEvent):
 
 
     def __init__(self, model_name, obj_id, window, group=None, parent=None,
-            parent_name='', new=False):
+            parent_name=''):
         super(Record, self).__init__()
         self.window = window
         self.model_name = model_name
@@ -63,19 +63,13 @@ class Record(SignalEvent):
         self.group = group
         if group is not None:
             assert model_name == group.model_name
-        self.value = {}
         self.state_attrs = {}
         self.__modified = False
         self.modified_fields = {}
         self._timestamp = None
         self.attachment_count = -1
         self.next = {} # Used in Group list
-        for key, val in self.group.fields.items():
-            self.value[key] = val.create(self)
-            if (new and val.attrs['type']=='one2many') \
-                    and (val.attrs.get('mode','tree,form').startswith('form')):
-                record = self.value[key].new()
-                self.value[key].add(record)
+        self.value = {}
 
     def __getitem__(self, name):
         if name not in self._loaded and self.id > 0:
@@ -108,8 +102,6 @@ class Record(SignalEvent):
             except Exception, exception:
                 values = common.process_exception(exception, self.window, *args)
                 if not values:
-                    log = logging.getLogger('record')
-                    log.error('%s' % exception.args[-1])
                     values = [{'id': x} for x in ids]
             id2value = dict((value['id'], value) for value in values)
             if ids != [self.id]:
@@ -260,8 +252,9 @@ class Record(SignalEvent):
             self.signal('record-changed')
         return change
 
-    def validate(self):
-        self._check_load()
+    def validate(self, check_load=True):
+        if check_load:
+            self._check_load()
         res = True
         for field in self.group.fields.itervalues():
             if not field.validate(self):
@@ -342,7 +335,7 @@ class Record(SignalEvent):
         if self.id < 0:
             return
         self['*']
-        self.validate()
+        self.validate(check_load=False)
 
     def expr_eval(self, expr, check_load=False):
         if not isinstance(expr, basestring):
@@ -406,7 +399,7 @@ class Record(SignalEvent):
             elif isinstance(self.group.fields[fieldname],
                     field.ReferenceField):
                 if value:
-                    ref_mode, ref_id = value.split(',', 1)
+                    ref_model, ref_id = value.split(',', 1)
                     if fieldname + '.rec_name' in res:
                         value = ref_model, (ref_id,
                                 res[fieldname + '.rec_name'])
@@ -459,9 +452,17 @@ class Record(SignalEvent):
         if self.attachment_count < 0 or reload:
             args = ('model', 'ir.attachment', 'search_count', [
                 ('resource', '=', '%s,%s' % (self.model_name, self.id)),
-                ])
+                ], rpc.CONTEXT)
             try:
                 self.attachment_count = rpc.execute(*args)
-            except:
+            except Exception:
                 return 0
         return self.attachment_count
+
+    def destroy(self):
+        super(Record, self).destroy()
+        self.window = None
+        self.parent = None
+        self.group = None
+        self.value = None
+        self.next = None
