@@ -50,8 +50,7 @@ class Screen(SignalEvent):
         self.parent_name = None
         self.__window = window
         self.__group = None
-        self.group = Group(model_name, {}, self.window, context=self.context,
-                readonly=readonly)
+        self.new_group()
         self.__current_record = None
         self.current_record = None
         self.screen_container = ScreenContainer()
@@ -88,20 +87,29 @@ class Screen(SignalEvent):
                         self.fields_view_tree = rpc.execute('model',
                                 self.model_name, 'fields_view_get', False,
                                 'tree', ctx)
-                    except:
+                    except Exception:
                         return
                 self.filter_widget = Form(self.fields_view_tree['arch'],
                         self.fields_view_tree['fields'], self.model_name,
                         self.window, self.domain, (self, self.search_filter),
                         self.context)
                 self.screen_container.add_filter(self.filter_widget.widget,
-                        self.search_filter, self.search_clear)
+                        self.search_filter, self.search_clear,
+                        self.search_prev, self.search_next)
                 self.filter_widget.set_limit(self.limit)
                 self.filter_widget.value = self.search_value
             self.screen_container.show_filter()
         else:
             self.screen_container.hide_filter()
 
+    def search_prev(self, widget=None):
+        self.filter_widget.prev()
+        self.search_filter()
+
+    def search_next(self, widget=None):
+        self.filter_widget.next()
+        self.search_filter()
+
     def search_clear(self, widget=None):
         self.filter_widget.clear()
         self.clear()
@@ -143,8 +151,14 @@ class Screen(SignalEvent):
                                 self.model_name, 'search_count', values, ctx)
                 else:
                     self.search_count = len(ids)
-        except:
+        except Exception:
             ids = []
+        self.screen_container.but_prev.set_sensitive(bool(offset))
+        if (len(ids) == limit
+                and self.search_count > limit + offset):
+            self.screen_container.but_next.set_sensitive(True)
+        else:
+            self.screen_container.but_next.set_sensitive(False)
         if only_ids:
             return ids
         self.clear()
@@ -178,6 +192,10 @@ class Screen(SignalEvent):
 
     group = property(__get_group, __set_group)
 
+    def new_group(self, readonly=False):
+        self.group = Group(self.model_name, {}, self.window,
+                context=self.context, readonly=readonly)
+
     def _group_cleared(self, group, signal):
         for view in self.views:
             if hasattr(view, 'reload'):
@@ -201,11 +219,11 @@ class Screen(SignalEvent):
         self.__current_record = record
         try:
             offset = int(self.filter_widget.get_offset())
-        except:
+        except Exception:
             offset = 0
         try:
             pos = self.group.index(record)
-        except:
+        except Exception:
             pos = -1
         self.signal('record-message', (pos + offset, len(self.group) + offset,
             self.search_count, record and record.id))
@@ -239,9 +257,14 @@ class Screen(SignalEvent):
     def destroy(self):
         for view in self.views:
             view.destroy()
-            del view
         self.group.signal_unconnect(self)
-        del self.views
+        self.group.destroy()
+        self.parent = None
+        self.__window = None
+        self.__group = None
+        self.__current_record = None
+        self.screen_container = None
+        self.widget = None
 
     def switch_view(self, view_type=None, default=True, context=None):
         self.current_view.set_value()
@@ -292,8 +315,9 @@ class Screen(SignalEvent):
             ctx.update(rpc.CONTEXT)
             ctx.update(self.context)
             args = ('model', self.model_name, 'fields_view_get',
-                    view_id, view_type, ctx,
-                    self.parent and False or CONFIG['form.toolbar'])
+                    view_id, view_type,
+                    self.parent and False or CONFIG['form.toolbar'],
+                    ctx)
             try:
                 view = rpc.execute(*args)
             except Exception, exception:
@@ -506,7 +530,7 @@ class Screen(SignalEvent):
                 context.update(rpc.CONTEXT)
                 context.update(self.context)
                 context['_timestamp'] = self.current_record.get_timestamp()
-                reload_ids = self.group.on_write_ids(record_id)
+                reload_ids = self.group.on_write_ids([record_id])
                 if reload_ids and record_id in reload_ids:
                     reload_ids.remove(record_id)
                 args = ('model', self.model_name, 'delete', [record_id],
@@ -599,7 +623,8 @@ class Screen(SignalEvent):
             if self.current_view.view_type == 'calendar' and \
                     len(self.views) > 1:
                 self.switch_view()
-            self.current_view.display()
+            for view in self.views:
+                view.display()
             self.current_view.widget.set_sensitive(
                     bool(self.group \
                             or (self.current_view.view_type != 'form') \
