@@ -104,7 +104,7 @@ class Button(object):
                     icon = gtk.Image()
                     icon.set_from_stock(stock, gtk.ICON_SIZE_SMALL_TOOLBAR)
                     self.widget.set_image(icon)
-                except:
+                except Exception:
                     log = logging.getLogger('common')
                     log.warning(_('Wrong icon for the button!'))
             else:
@@ -518,7 +518,7 @@ class ParserForm(ParserInterface):
                     continue
                 for attr_name in ('relation', 'domain', 'selection',
                         'relation_field', 'string', 'views', 'invisible',
-                        'add_remove', 'sort', 'context'):
+                        'add_remove', 'sort', 'context', 'size'):
                     if attr_name in fields[name].attrs and \
                             not attr_name in attrs:
                         attrs[attr_name] = fields[name].attrs[attr_name]
@@ -646,7 +646,8 @@ class ParserForm(ParserInterface):
         obj_id = self.screen.current_record.save(force_reload=False)
         try:
             lang_ids = rpc.execute('model', 'ir.lang',
-                    'search', [('translatable', '=', '1')])
+                    'search', [('translatable', '=', '1')],
+                    rpc.CONTEXT)
         except Exception, exception:
             common.process_exception(exception, self.window)
             return False
@@ -657,9 +658,11 @@ class ParserForm(ParserInterface):
             return False
         try:
             lang_ids += rpc.execute('model', 'ir.lang',
-                    'search', [('code', '=', 'en_US')])
+                    'search', [('code', '=', 'en_US')],
+                    rpc.CONTEXT)
             langs = rpc.execute('model', 'ir.lang',
-                    'read', lang_ids, ['code', 'name'])
+                    'read', lang_ids, ['code', 'name'],
+                    rpc.CONTEXT)
         except Exception, exception:
             common.process_exception(exception, self.window)
             return False
