@@ -70,7 +70,7 @@ class AdaptModelGroup(gtk.GenericTreeModel):
                 if old_pos != pos:
                     new_order[old_pos] = pos
                 pos += 1
-            except:
+            except Exception:
                 continue
         self.group.sort(lambda x, y: \
                 cmp(new_order[ids2pos[x.id]], new_order[ids2pos[y.id]]))
@@ -281,7 +281,8 @@ class ViewList(ParserView):
             'ids': obj_ids,
         }
         value = Action._exec_action(act, self.window, data, {})
-        self.screen.reload(writen=True)
+        if self.screen:
+            self.screen.reload(writen=True)
         return value
 
 
@@ -368,8 +369,9 @@ class ViewList(ParserView):
             info, etime):
         treeview.emit_stop_by_name('drag-data-received')
         if treeview.sequence:
+            field = self.screen.group.fields[treeview.sequence]
             for record in self.screen.group:
-                if record[treeview.sequence].get_state_attrs(
+                if field.get_state_attrs(
                         record).get('readonly', False):
                     return
         if not selection.data:
@@ -481,13 +483,16 @@ class ViewList(ParserView):
                 self.store.added(group, signal[1])
             elif signal[0] == 'record-removed':
                 self.store.removed(group, signal[1])
+            elif signal[0] == 'group-cleared':
+                self.store = None
+                self.widget_tree.set_model(self.store)
         self.display()
 
     def cancel(self):
         pass
 
     def __str__(self):
-        return 'ViewList (%s)' % self.screen.model_name
+        return 'ViewList (%d)' % id(self)
 
     def __getitem__(self, name):
         return None
@@ -512,12 +517,12 @@ class ViewList(ParserView):
                 try:
                     rpc.execute('model', 'ir.ui.view_tree_width', 'set_width',
                             self.screen.model_name, fields, rpc.CONTEXT)
-                except:
+                except Exception:
                     pass
         self.widget_tree.destroy()
-        del self.screen
-        del self.widget_tree
-        del self.widget
+        self.screen = None
+        self.widget_tree = None
+        self.widget = None
 
     def __sig_switch(self, treeview, path, column):
         if column._type == 'button':
