@@ -6,7 +6,7 @@ from tryton.gui.window.view_form.view.interface import ParserInterface
 from tryton.gui.window.win_search import WinSearch
 from tryton.gui.window.win_form import WinForm
 from tryton.gui.window.view_form.screen import Screen
-from tryton.gui.window.view_form.widget_search.form import _LIMIT
+from tryton.config import CONFIG
 import tryton.rpc as rpc
 from tryton.common import DT_FORMAT, DHM_FORMAT, COLORS, node_attributes, \
         TRYTON_ICON, HM_FORMAT
@@ -374,7 +374,7 @@ class Date(Char):
             return False
         try:
             date = datetime.date(*time.strptime(text, self.display_format)[:3])
-        except:
+        except Exception:
             return False
         return common.datetime_strftime(date, self.server_format)
 
@@ -386,6 +386,7 @@ class Datetime(Date):
         super(Datetime, self).__init__(field_name, model_name, treeview,
                 window, attrs=attrs)
         self.display_format = date_format() + ' ' + HM_FORMAT
+        self.renderer.format = self.display_format
 
     def get_textual_value(self, record):
         value = record[self.field_name].get_client(record)
@@ -401,7 +402,7 @@ class Datetime(Date):
                 sdt = szone.localize(date, is_dst=True)
                 ldt = sdt.astimezone(lzone)
                 date = ldt
-            except:
+            except Exception:
                 pass
         return common.datetime_strftime(date, self.display_format)
 
@@ -411,7 +412,7 @@ class Datetime(Date):
         try:
             date = datetime.datetime(*time.strptime(text,
                 self.display_format)[:6])
-        except:
+        except Exception:
             return False
         if 'timezone' in rpc.CONTEXT:
             try:
@@ -421,7 +422,7 @@ class Datetime(Date):
                 ldt = lzone.localize(date, is_dst=True)
                 sdt = ldt.astimezone(szone)
                 date = sdt
-            except:
+            except Exception:
                 pass
         return common.datetime_strftime(date, self.server_format)
 
@@ -455,7 +456,7 @@ class Float(Char):
     def value_from_text(self, record, text):
         try:
             return locale.atof(text)
-        except:
+        except Exception:
             return 0.0
 
 
@@ -629,7 +630,8 @@ class M2M(Char):
                     domain]
         else:
             dom = domain
-        args = ('model', relation, 'search', dom, 0, _LIMIT, None, context)
+        args = ('model', relation, 'search', dom, 0, CONFIG['client.limit'],
+                None, context)
         try:
             ids = rpc.execute(*args)
         except Exception, exception:
@@ -678,8 +680,8 @@ class Selection(Char):
         self.selection = selection[:]
         if 'relation' in self.attrs:
             args = ('model', self.attrs['relation'], 'search_read',
-                    self.attrs.get('domain', []), 0, None, None, rpc.CONTEXT,
-                    ['rec_name'])
+                    self.attrs.get('domain', []), 0, None, None, ['rec_name'],
+                    rpc.CONTEXT)
             try:
                 result = rpc.execute(*args)
             except Exception, exception:
@@ -822,7 +824,7 @@ class ProgressBar(object):
 
 class Button(object):
 
-    def __init__(self, treeview, windown, screen, attrs=None):
+    def __init__(self, treeview, window, screen, attrs=None):
         super(Button, self).__init__()
         self.attrs = attrs or {}
         self.renderer = CellRendererButton(attrs.get('string', _('Unknown')))
