@@ -256,7 +256,7 @@ class WinImport(object):
         try:
             data = csv.reader(open(fname, 'rb'), quotechar=csvdel,
                     delimiter=csvsep)
-        except:
+        except Exception:
             common.warning(_('Error opening CSV file'), self.dialog,
                     _('Error'))
             return True
@@ -352,7 +352,8 @@ class WinImport(object):
             datas.append([x.decode(csv_data['combo']).encode('utf-8') \
                     for x in line])
         try:
-            res = rpc.execute('model', model, 'import_data', fields, datas)
+            res = rpc.execute('model', model, 'import_data', fields, datas,
+                    rpc.CONTEXT)
         except Exception, exception:
             common.process_exception(exception, self.dialog)
             return False
