@@ -48,7 +48,7 @@ class Wizard(SignalEvent):
         self.context = context
         if not 'form' in datas:
             datas['form'] = {}
-        args = ('wizard', action, 'create')
+        args = ('wizard', action, 'create', rpc.CONTEXT)
         try:
             self.wiz_id = rpc.execute(*args)
         except Exception, exception:
@@ -129,7 +129,7 @@ class Wizard(SignalEvent):
             rpc.execute('wizard', self.action, 'delete', self.wiz_id)
             #XXX to remove when company displayed in status bar
             rpc.context_reload()
-        except:
+        except Exception:
             pass
         Main.get_main()._win_del(self.widget)
 
